@@ -24,19 +24,7 @@
 #
 ###############################################################################
 
-
-from __future__ import absolute_import
-
-# we use the following in code examples, so it must be part of
-# out public API
-from autobahn.util import utcnow, utcstr
-
-__version__ = u"0.11.0"
+__version__ = u'0.13.1'
 """
 AutobahnPython library version.
 """
-
-__all__ = (
-    'utcnow',
-    'utcstr',
-)
