@@ -26,6 +26,8 @@
 
 from __future__ import absolute_import
 
+import hashlib
+
 from twisted.internet.defer import Deferred
 from twisted.internet.address import IPv4Address, UNIXAddress
 try:
@@ -42,7 +44,8 @@ except ImportError:
 
 __all = (
     'sleep',
-    'peer2str'
+    'peer2str',
+    'transport_channel_id'
 )
 
 
@@ -86,3 +89,42 @@ def peer2str(addr):
         res = u"?:{0}".format(addr)
 
     return res
+
+
+def transport_channel_id(transport, is_server, channel_id_type):
+    """
+    Application-layer user authentication protocols are vulnerable to generic
+    credential forwarding attacks, where an authentication credential sent by
+    a client C to a server M may then be used by M to impersonate C at another
+    server S. To prevent such credential forwarding attacks, modern authentication
+    protocols rely on channel bindings. For example, WAMP-cryptosign can use
+    the tls-unique channel identifier provided by the TLS layer to strongly bind
+    authentication credentials to the underlying channel, so that a credential
+    received on one TLS channel cannot be forwarded on another.
+
+    """
+    if channel_id_type is None:
+        return None
+
+    if channel_id_type not in [u'tls-unique']:
+        raise Exception("invalid channel ID type {}".format(channel_id_type))
+
+    if hasattr(transport, '_tlsConnection'):
+        # Obtain latest TLS Finished message that we expected from peer, or None if handshake is not completed.
+        # http://www.pyopenssl.org/en/stable/api/ssl.html#OpenSSL.SSL.Connection.get_peer_finished
+
+        if is_server:
+            # for routers (=servers), the channel ID is based on the TLS Finished message we
+            # expected to receive from the client
+            tls_finished_msg = transport._tlsConnection.get_peer_finished()
+        else:
+            # for clients, the channel ID is based on the TLS Finished message we sent
+            # to the router (=server)
+            tls_finished_msg = transport._tlsConnection.get_finished()
+
+        m = hashlib.sha256()
+        m.update(tls_finished_msg)
+        return m.digest()
+
+    else:
+        return None
